@@ -35,17 +35,19 @@ class FidapClient:
         """
         if db:
             self._custom_db = db
-        return self.api({'func': 'sql', 'sql': sql, **self.api_keys})
+        return self.api({'func': 'sql', 'sql_query': sql, **self.api_keys})
 
     def api(self, json: Dict[str, Any]):
         """
         :param json: JSON contain function and sql values
         :return: return Pandas Dataframe
         """
-        df = None
-        response = requests.post(f"{BASE_URL}/api", json=json).json()
-        if response['success']:
-            df = pd.read_json(response['result'])
+        response = requests.post(f"{BASE_URL}/api/v1/query/run/query/", json=json)
+        if response.status_code == 401:
+            return response.json()['detail']
+        if response.status_code == 400:
+            return response.json()['detail']
+        df = pd.read_json(response.json()['data'])
         return df
 
     def send_email(self, df: pd.DataFrame, emails: List[str], file_name: str, rows: int = 1000, cols: int = 30) -> bool:
@@ -60,15 +62,15 @@ class FidapClient:
         df = df.iloc[0:rows, 0:cols]
         data = {
             'emails': emails,
-            'json': df.to_json(),
+            'df_data': df.to_json(),
             'file_name': file_name,
             **self.api_keys
         }
-        response = requests.post(f"{BASE_URL}/email/send/", json=data).json()
+        response = requests.post(f"{BASE_URL}/api/v1/common/send/email/", json=data).json()
         return response['success']
 
 
-def fidap_client(api_key, db='sf', api_secret=None):
+def fidap_client(api_key, db='sf_gcp', api_secret=None):
     """
     :param db: Sting
     :param api_key: String
